" Menu Translations:	Slovak
" Translated By:	Martin Lacko <lacko@host.sk>
" Last Change:		2002 May 27

if has("win32") || has("win16") || has("dos16") || has("dos32")
	source <sfile>:p:h/menu_sk_sk.1250.vim
else
	source <sfile>:p:h/menu_sk_sk.iso_8859-2.vim
endif
